==> vradi-swing-0.0.1-sources.jar: com/jurismarches/vradi/ui/email/ClientLine.java <==
package com.jurismarches.vradi.ui.email;

import com.jurismarches.vradi.ui.email.*;
import java.awt.*;
import java.awt.event.*;
import java.beans.*;
import java.io.*;
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import jaxx.runtime.swing.JAXXButtonGroup;
import jaxx.runtime.swing.HBox;
import jaxx.runtime.swing.VBox;
import jaxx.runtime.swing.Table;
import jaxx.runtime.Util;
import jaxx.runtime.SwingUtil;
import static org.nuiton.i18n.I18n._;
import static jaxx.runtime.Util.createImageIcon;
import com.jurismarches.vradi.entities.*;
import com.jurismarches.vradi.services.dto.*;
import com.jurismarches.vradi.VradiContext;
import jaxx.runtime.swing.editor.*;
import jaxx.runtime.swing.EntityComboBox;
import static jaxx.runtime.validator.BeanValidatorUtil.convert;
import static jaxx.runtime.SwingUtil.getStringValue;
import static org.nuiton.i18n.I18n.n_;
import com.jurismarches.vradi.entities.Form;
import com.jurismarches.vradi.entities.Client;
import jaxx.runtime.DataBindingListener;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class ClientLine extends jaxx.runtime.swing.Table implements jaxx.runtime.JAXXObject {
    public static final Log log = LogFactory.getLog(com.jurismarches.vradi.ui.email.ClientLine.class);
    private static String $jaxxObjectDescriptor = "H4sIAAAAAAAAAI1TPW8TQRAdH7EdJ3xbWEEkUgIGJIo10AZBkJFFogMkTBHhhrVvFa+1d7fs7iUHBeIn8BOgp0Gio0IU1BQ0iL+AEAUtYnbP9uXjInBxd56Z9/bN7Ju3P6CsFayMaJoSlUSGh4xs3N7cfNAfsYG5w/RAcWliBdmv5IHXg/lgGtcGLvR8C2+N4a12HMo4YtEu9KoPc9o8E0wPGTMGlvYiBlq3utP0aioTNWGdiipiff3rp/cqePnGA0glqrOtLP8LlXcy44PHAwOn8aRt2hI02kIZikdbqPeYjbUF1fo+DdlTeAFVHyqSKiQzcP7/W3YcDp9KA9XmI9oX7KqBK4M4JKNEcR1SNRgyTbYVDThJOGEh5YK0BUdGn0dMSkdQMVAZuKCBS4egMckNx78ZOkfWm12nbD3CPBX8OVPXkMZNC7kkF0yRTDw5UJnTzDY3fNpn4jqOzU4oJXoHB0ayqC2qTWvLxra6v9D1Py5UcG7PdaERSG6E/KZKPSirBMMGFnoHvfMQU5lrFva5xhK67J9G/euH7+87E6t4ePaZwtJdTscrlCqWTNmJGjiR+SQxXLTuUbnag5pmAtfErcFigbDuOI3i8LxTFk4snNyleogU5eq3j58aT74cAa8DcyKmQYfa+nWomaHCKcQiSOWtNafo6M4sPk9abQZmDEvRBsdvBNTQ5T6PAhzuzRRHsFgwgqmOfu3z73r33dpkDCWUdfbQ8nwU5cdQ4ZFAL7qdGa9D4Y7MS82SIM5tX7QIJfuuy7GvltxzpajPchgHma+aaWJfF51q+3XZkTSQ5C9KqGabxgQAAA==";
    private static final long serialVersionUID = 1L;
    protected java.util.List<Object> $activeBindings = new ArrayList<Object>();
    protected java.util.Map<String,Object> $bindingSources = new HashMap<String,Object>();
    protected Map<String,Object> $objectMap = new HashMap<String,Object>();
    protected java.util.Map<?,?> $previousValues = new java.util.HashMap<Object,Object>();
    protected com.jurismarches.vradi.entities.Client client;
    protected final jaxx.runtime.JAXXContext delegateContext = new jaxx.runtime.context.DefaultJAXXContext();
    protected javax.swing.JTable table;
    private javax.swing.JLabel $JLabel2;
    private ClientLine $Table0 = this;
    private boolean allComponentsCreated;
    private boolean contextInitialized = true;
    private PropertyChangeListener $DataSource4 = new DataBindingListener(this, "table.model");

    /* begin raw body code */
    java.util.List<Form> forms;
    
    
    public void setForms(java.util.List<Form> forms) {
        this.forms = forms;
        table.setModel(getTableModel());
    }
    
    protected EmailHandler getHandler() {
        return getContextValue(EmailHandler.class);
    }
    
    protected VradiContext getVradiContext() {
        return VradiContext.get();
    }
    
    protected javax.swing.table.TableModel getTableModel() {
        Object[][] data = new Object[forms.size()][1];
        for(int i = 0 ; i < forms.size() ; i++) {
            data[i][1] = forms.get(i);    
        }
        Object[] columnName = new Object[]{"Formulaire"};
        return new javax.swing.table.DefaultTableModel(data, columnName);
    }
    /* end raw body code */
    /*---------------------------------------------------------------------------------*/
    /*-- Statics methods --------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public static jaxx.runtime.JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return jaxx.runtime.Util.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- Constructors -----------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public ClientLine() {
        $initialize();
    }

    public ClientLine(jaxx.runtime.JAXXContext parentContext) {
        jaxx.runtime.Util.initContext(this, parentContext);
        $initialize();
    }

    /*---------------------------------------------------------------------------------*/
    /*-- JAXXObject implementation ----------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    @Override
    public void applyDataBinding(String $binding) {
        if ("table.model".equals($binding)) {    
            addPropertyChangeListener("tableModel", $DataSource4);
        }
        processDataBinding($binding);
    }

    @Override
    public void firePropertyChange(String propertyName, Object oldValue, Object newValue) {
        super.firePropertyChange(propertyName, oldValue, newValue);
    }

    @Override
    public Map<String,Object> get$objectMap() {
        return $objectMap;
    }

    @Override
    public java.lang.Object getObjectById(String id) {
        return $objectMap.get(id);
    }

    @Override
    public void processDataBinding(String dest) {
        processDataBinding(dest, false);
    }

    public void processDataBinding(String $dest, boolean $force) {
        if (!$force && $activeBindings.contains($dest)) { 
            return;
        }
        $activeBindings.add($dest);
        try {
            if ("table.model".equals($dest)) {
                table.setModel(getTableModel());
            }
        } finally {
            $activeBindings.remove($dest);
        }
    }

    @Override
    public void removeDataBinding(String $binding) {
        if ("table.model".equals($binding)) {    
            removePropertyChangeListener("tableModel", $DataSource4);
        }
    }

    /*---------------------------------------------------------------------------------*/
    /*-- JAXXContext implementation ---------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    @Override
    public <T> T getContextValue(Class<T> clazz) {
        return delegateContext.getContextValue(clazz, null);
    }

    @Override
    public <T> T getContextValue(Class<T> clazz, String name) {
        return delegateContext.getContextValue(clazz, name);
    }

    @Override
    public jaxx.runtime.JAXXContext getDelegateContext() {
        return delegateContext;
    }

    @Override
    public <O extends Container> O getParentContainer(Class<O> clazz) {
        return Util.getParentContainer(this, clazz);
    }

    @Override
    public <O extends Container> O getParentContainer(Object source, Class<O> clazz) {
        return Util.getParentContainer(source, clazz);
    }

    @Override
    public <T> void removeContextValue(Class<T> clazz) {
        delegateContext.removeContextValue(clazz, null);
    }

    @Override
    public <T> void removeContextValue(Class<T> clazz, String name) {
        delegateContext.removeContextValue(clazz, name);
    }

    @Override
    public <T> void setContextValue(T o) {
        delegateContext.setContextValue(o, null);
    }

    @Override
    public <T> void setContextValue(T o, String name) {
        delegateContext.setContextValue(o, name);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public acessor methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public java.util.List<Object> get$activeBindings() {
        return $activeBindings;
    }

    public java.util.Map<String,Object> get$bindingSources() {
        return $bindingSources;
    }

    public com.jurismarches.vradi.entities.Client getClient() {
        return client;
    }

    public javax.swing.JTable getTable() {
        return table;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public mutator methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public void setClient(com.jurismarches.vradi.entities.Client newValue) {
        com.jurismarches.vradi.entities.Client oldValue = this.client;
        this.client = newValue;
        firePropertyChange("client", oldValue, newValue);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- protected acessors methods ---------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    protected javax.swing.JLabel get$JLabel2() {
        return $JLabel2;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- ui creation methods ----------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        // inline complete setup of $Table0
        add($JLabel2, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, 10, 0, new Insets(3, 3, 3, 3), 0, 0));
        add(table, new GridBagConstraints(1, 0, 1, 1, 0.0, 0.0, 10, 0, new Insets(3, 3, 3, 3), 0, 0));
        // init data bindings
        $JLabel2.setText(_(client != null ? client.getName() : ""));
        applyDataBinding("table.model");
    }

    private void $initialize() {
        if (allComponentsCreated || !contextInitialized) {
            return;
        }
        $objectMap.put("$Table0", this);
        createClient();
        forms = new ArrayList<Form>();
        // inline creation of $JLabel2
        $objectMap.put("$JLabel2", $JLabel2 = new javax.swing.JLabel());
        $JLabel2.setName("$JLabel2");
        createTable();
        // inline creation of $Table0
        setName("$Table0");
        
        $completeSetup();
    }

    protected void createClient() {
        $objectMap.put("client", client = null);
    }

    protected void createTable() {
        $objectMap.put("table", table = new javax.swing.JTable());
        table.setName("table");
    }

}

==> vradi-swing-0.0.2-sources.jar: com/jurismarches/vradi/ui/email/ClientLine.java <==
package com.jurismarches.vradi.ui.email;

import com.jurismarches.vradi.ui.email.*;
import java.awt.*;
import java.awt.event.*;
import java.beans.*;
import java.io.*;
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import jaxx.runtime.swing.JAXXButtonGroup;
import jaxx.runtime.swing.HBox;
import jaxx.runtime.swing.VBox;
import jaxx.runtime.swing.Table;
import jaxx.runtime.Util;
import jaxx.runtime.SwingUtil;
import static org.nuiton.i18n.I18n._;
import static jaxx.runtime.Util.createImageIcon;
import com.jurismarches.vradi.entities.*;
import com.jurismarches.vradi.services.dto.*;
import com.jurismarches.vradi.VradiContext;
import jaxx.runtime.swing.editor.*;
import jaxx.runtime.swing.EntityComboBox;
import static jaxx.runtime.validator.BeanValidatorUtil.convert;
import static jaxx.runtime.SwingUtil.getStringValue;
import static org.nuiton.i18n.I18n.n_;
import com.jurismarches.vradi.entities.Form;
import org.jdesktop.swingx.JXTable;
import jaxx.runtime.DataBindingListener;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class ClientLine extends jaxx.runtime.swing.Table implements jaxx.runtime.JAXXObject {
    public static final Log log = LogFactory.getLog(com.jurismarches.vradi.ui.email.ClientLine.class);
    private static String $jaxxObjectDescriptor = "H4sIAAAAAAAAAI1TQU9TQRCeFgoUFNFGggES0KqJh616xSgGQ4QUTagHYi9s+zZ067731t158PRg/An+BL17MfHmyXjw7MGL8S8Y48GrcXZf6QOpgXfYfZmd+eabmW/e/oCSNbDY5WnKTBKhDAVbv7u19bDVFW28J2zbSI2xgewrFKHYhImgb7cIl5p1F17rhddW4lDHkYgORC/VYdziMyVsRwhEmD8c0ba21ug/L6U6MfuofVKDUF//+ll8Fbx8UwRINbFzpSwcF5VXMlyHogwQzlGmXV5TPNohGkZGO8T3tLOtKG7tAx6Kp/ACRusworkhMISLJy/ZY/j4VCOMVh/xlhLXEa6145B1EyNtyE27IyzbNTyQLJFMhFwqtqIkIdZlJLT2ACMI421vdJQQphxF5mizjHbuV6k2PI+1SKLkSj4X5gbCFd8byqulEoZlVNkRzxxmrLpe5y2hblKTXLKU2T3KwzKrcyr3fUvoCkOYjc0O65JCnmCsM/+UrW/5snsRBmYPTYnmz/L55wMqNKFkEjIjzDSPSmaTnjKxzPwjFgfoX/9MV75++P5+dV8hQ5T7/EDXAwKnyWkTa2FQutRnMnkkKFVtg+ulJpStULQdXv1zA4g1es9EjvKd9WNy4ew+tx2CKI1++/hpevvLEBRXYVzFPFjlzn8Nytgx1IVYBam+s+wZndobo3PKcUMYRpGS/CZvBRz5QktGAbX3dkotmBvQgj6PVvnz70rj3fJ+GwpE68J/3fNWlB7DiIwUSdCvSm8LBq7GhLYiCeJc7YP0X3B3RfcENu/PxUF1TvIE401hSY4bceBzVNPEXZc9ffd31aNNnwCtFBKGOgbkL+a11JkLBQAA";
    private static final long serialVersionUID = 1L;
    protected java.util.List<Object> $activeBindings = new ArrayList<Object>();
    protected java.util.Map<String,Object> $bindingSources = new HashMap<String,Object>();
    protected Map<String,Object> $objectMap = new HashMap<String,Object>();
    protected java.util.Map<?,?> $previousValues = new java.util.HashMap<Object,Object>();
    protected java.lang.String clientName;
    protected final jaxx.runtime.JAXXContext delegateContext = new jaxx.runtime.context.DefaultJAXXContext();
    protected org.jdesktop.swingx.JXTable table;
    private javax.swing.JLabel $JLabel2;
    private ClientLine $Table0 = this;
    private boolean allComponentsCreated;
    private boolean contextInitialized = true;
    private PropertyChangeListener $DataSource3 = new DataBindingListener(this, "$JLabel2.text");
    private PropertyChangeListener $DataSource5 = new DataBindingListener(this, "table.model");

    /* begin raw body code */
    java.util.List<Form> forms;
    
    
    public void setForms(java.util.List<Form> forms) {
        this.forms = forms;
        table.setModel(getTableModel());
        //table.packAll();
    }
    
    protected EmailHandler getHandler() {
        return getContextValue(EmailHandler.class);
    }
    
    protected VradiContext getVradiContext() {
        return VradiContext.get();
    }
    
    protected javax.swing.table.TableModel getTableModel() {
        Object[][] data = new Object[forms.size()][1];
        for(int i = 0 ; i < forms.size() ; i++) {
            data[i][0] = forms.get(i).getName();    
        }
        Object[] columnName = new Object[]{_("vradi.forms")};
        return new javax.swing.table.DefaultTableModel(data, columnName);
    }
    /* end raw body code */
    /*---------------------------------------------------------------------------------*/
    /*-- Statics methods --------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public static jaxx.runtime.JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return jaxx.runtime.Util.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- Constructors -----------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public ClientLine() {
        $initialize();
    }

    public ClientLine(jaxx.runtime.JAXXContext parentContext) {
        jaxx.runtime.Util.initContext(this, parentContext);
        $initialize();
    }

    /*---------------------------------------------------------------------------------*/
    /*-- JAXXObject implementation ----------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    @Override
    public void applyDataBinding(String $binding) {
        if ("$JLabel2.text".equals($binding)) {    
            addPropertyChangeListener("clientName", $DataSource3);
        } else if ("table.model".equals($binding)) {    
            addPropertyChangeListener("tableModel", $DataSource5);
        }
        processDataBinding($binding);
    }

    @Override
    public void firePropertyChange(String propertyName, Object oldValue, Object newValue) {
        super.firePropertyChange(propertyName, oldValue, newValue);
    }

    @Override
    public Map<String,Object> get$objectMap() {
        return $objectMap;
    }

    @Override
    public java.lang.Object getObjectById(String id) {
        return $objectMap.get(id);
    }

    @Override
    public void processDataBinding(String dest) {
        processDataBinding(dest, false);
    }

    public void processDataBinding(String $dest, boolean $force) {
        if (!$force && $activeBindings.contains($dest)) { 
            return;
        }
        $activeBindings.add($dest);
        try {
            if ("$JLabel2.text".equals($dest)) {
                $JLabel2.setText(_(getStringValue(getClientName())));
            } else if ("table.model".equals($dest)) {
                table.setModel(getTableModel());
            }
        } finally {
            $activeBindings.remove($dest);
        }
    }

    @Override
    public void removeDataBinding(String $binding) {
        if ("$JLabel2.text".equals($binding)) {    
            removePropertyChangeListener("clientName", $DataSource3);
        } else if ("table.model".equals($binding)) {    
            removePropertyChangeListener("tableModel", $DataSource5);
        }
    }

    /*---------------------------------------------------------------------------------*/
    /*-- JAXXContext implementation ---------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    @Override
    public <T> T getContextValue(Class<T> clazz) {
        return delegateContext.getContextValue(clazz, null);
    }

    @Override
    public <T> T getContextValue(Class<T> clazz, String name) {
        return delegateContext.getContextValue(clazz, name);
    }

    @Override
    public jaxx.runtime.JAXXContext getDelegateContext() {
        return delegateContext;
    }

    @Override
    public <O extends Container> O getParentContainer(Class<O> clazz) {
        return Util.getParentContainer(this, clazz);
    }

    @Override
    public <O extends Container> O getParentContainer(Object source, Class<O> clazz) {
        return Util.getParentContainer(source, clazz);
    }

    @Override
    public <T> void removeContextValue(Class<T> clazz) {
        delegateContext.removeContextValue(clazz, null);
    }

    @Override
    public <T> void removeContextValue(Class<T> clazz, String name) {
        delegateContext.removeContextValue(clazz, name);
    }

    @Override
    public <T> void setContextValue(T o) {
        delegateContext.setContextValue(o, null);
    }

    @Override
    public <T> void setContextValue(T o, String name) {
        delegateContext.setContextValue(o, name);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public acessor methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public java.util.List<Object> get$activeBindings() {
        return $activeBindings;
    }

    public java.util.Map<String,Object> get$bindingSources() {
        return $bindingSources;
    }

    public java.lang.String getClientName() {
        return clientName;
    }

    public org.jdesktop.swingx.JXTable getTable() {
        return table;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public mutator methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public void setClientName(java.lang.String newValue) {
        java.lang.String oldValue = this.clientName;
        this.clientName = newValue;
        firePropertyChange("clientName", oldValue, newValue);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- protected acessors methods ---------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    protected javax.swing.JLabel get$JLabel2() {
        return $JLabel2;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- ui creation methods ----------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        // inline complete setup of $Table0
        add($JLabel2, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, 12, 0, new Insets(3, 3, 3, 3), 0, 0));
        add(table, new GridBagConstraints(1, 0, 1, 1, 1.0, 0.0, 10, 1, new Insets(3, 3, 3, 3), 0, 0));
        // init data bindings
        applyDataBinding("$JLabel2.text");
        table.setAutoResizeMode(2);
        applyDataBinding("table.model");
    }

    private void $initialize() {
        if (allComponentsCreated || !contextInitialized) {
            return;
        }
        $objectMap.put("$Table0", this);
        createClientName();
        forms = new ArrayList<Form>();
        // inline creation of $JLabel2
        $objectMap.put("$JLabel2", $JLabel2 = new javax.swing.JLabel());
        $JLabel2.setName("$JLabel2");
        createTable();
        // inline creation of $Table0
        setName("$Table0");
        
        $completeSetup();
    }

    protected void createClientName() {
        $objectMap.put("clientName", clientName = null);
    }

    protected void createTable() {
        $objectMap.put("table", table = new org.jdesktop.swingx.JXTable());
        table.setName("table");
    }

}
